Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorEike Stepper2011-09-14 02:33:07 +0000
committerEike Stepper2011-09-14 02:33:07 +0000
commit4cda691d7b705982d795ff2f8ff83517d545b7e2 (patch)
tree0b7cba4359ea386cf7c4b6019672f3861bbc156c /plugins
parentec30303c5443f23acabc0901704561cec113b741 (diff)
downloadcdo-4cda691d7b705982d795ff2f8ff83517d545b7e2.tar.gz
cdo-4cda691d7b705982d795ff2f8ff83517d545b7e2.tar.xz
cdo-4cda691d7b705982d795ff2f8ff83517d545b7e2.zip
tutorials
Diffstat (limited to 'plugins')
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/model/article.ecore5
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/model/article.ecorediag6
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/ArticlePackage.java156
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/LinkTarget.java26
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ArticleImpl.java6
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ArticlePackageImpl.java20
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/CategoryImpl.java6
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ChapterImpl.java6
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/DocumentationImpl.java6
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ExternalTargetImpl.java7
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/JavaElementImpl.java96
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/LinkImpl.java20
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/LinkTargetImpl.java46
-rw-r--r--plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/StructuralElementImpl.java32
-rw-r--r--plugins/org.eclipse.net4j.db.doc/build.xml19
-rw-r--r--plugins/org.eclipse.net4j.doc/build.xml19
-rw-r--r--plugins/org.eclipse.net4j.util.doc/build.xml19
17 files changed, 415 insertions, 80 deletions
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/model/article.ecore b/plugins/org.eclipse.emf.cdo.releng.doc/model/article.ecore
index a4e7ace72c..12c28c5f8f 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/model/article.ecore
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/model/article.ecore
@@ -68,8 +68,11 @@
<eOperations name="linkFrom" lowerBound="1" eType="ecore:EDataType http://www.eclipse.org/emf/2002/Ecore#//EString">
<eParameters name="source" lowerBound="1" eType="#//StructuralElement"/>
</eOperations>
- <eStructuralFeatures xsi:type="ecore:EAttribute" name="label" lowerBound="1" eType="ecore:EDataType http://www.eclipse.org/emf/2002/Ecore#//EString"
+ <eStructuralFeatures xsi:type="ecore:EAttribute" name="defaultLabel" eType="ecore:EDataType http://www.eclipse.org/emf/2002/Ecore#//EString"
changeable="false" volatile="true" transient="true" derived="true"/>
+ <eStructuralFeatures xsi:type="ecore:EAttribute" name="tooltip" lowerBound="1"
+ eType="ecore:EDataType http://www.eclipse.org/emf/2002/Ecore#//EString" changeable="false"
+ volatile="true" transient="true" derived="true"/>
</eClassifiers>
<eClassifiers xsi:type="ecore:EClass" name="Callout">
<eStructuralFeatures xsi:type="ecore:EReference" name="snippet" lowerBound="1"
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/model/article.ecorediag b/plugins/org.eclipse.emf.cdo.releng.doc/model/article.ecorediag
index c03f2a6368..03a3290a0b 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/model/article.ecorediag
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/model/article.ecorediag
@@ -199,8 +199,12 @@
<children xmi:type="notation:Node" xmi:id="_x5KOgNxQEeCpIJpgvmzkYA" type="1001">
<children xmi:type="notation:Node" xmi:id="_x5LcoNxQEeCpIJpgvmzkYA" type="4001"/>
<children xmi:type="notation:Node" xmi:id="_x5LcodxQEeCpIJpgvmzkYA" type="5001">
+ <children xmi:type="notation:Node" xmi:id="_GoP24N55EeCgeMAkr6dR9Q" type="2001">
+ <element xmi:type="ecore:EAttribute" href="article.ecore#//LinkTarget/defaultLabel"/>
+ <layoutConstraint xmi:type="notation:Location" xmi:id="_GoP24d55EeCgeMAkr6dR9Q"/>
+ </children>
<children xmi:type="notation:Node" xmi:id="_2UnMgNxYEeCpIJpgvmzkYA" type="2001">
- <element xmi:type="ecore:EAttribute" href="article.ecore#//LinkTarget/label"/>
+ <element xmi:type="ecore:EAttribute" href="article.ecore#//LinkTarget/tooltip"/>
<layoutConstraint xmi:type="notation:Location" xmi:id="_2UnMgdxYEeCpIJpgvmzkYA"/>
</children>
<styles xmi:type="notation:DrawerStyle" xmi:id="_x5LcotxQEeCpIJpgvmzkYA"/>
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/ArticlePackage.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/ArticlePackage.java
index 78e95e89ed..e4662a3d01 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/ArticlePackage.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/ArticlePackage.java
@@ -102,12 +102,20 @@ public interface ArticlePackage extends EPackage
int LINK_TARGET__ID = IDENTIFIABLE__ID;
/**
- * The feature id for the '<em><b>Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Default Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int LINK_TARGET__LABEL = IDENTIFIABLE_FEATURE_COUNT + 0;
+ int LINK_TARGET__DEFAULT_LABEL = IDENTIFIABLE_FEATURE_COUNT + 0;
+
+ /**
+ * The feature id for the '<em><b>Tooltip</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated
+ * @ordered
+ */
+ int LINK_TARGET__TOOLTIP = IDENTIFIABLE_FEATURE_COUNT + 1;
/**
* The number of structural features of the '<em>Link Target</em>' class. <!-- begin-user-doc --> <!-- end-user-doc
@@ -116,7 +124,7 @@ public interface ArticlePackage extends EPackage
* @generated
* @ordered
*/
- int LINK_TARGET_FEATURE_COUNT = IDENTIFIABLE_FEATURE_COUNT + 1;
+ int LINK_TARGET_FEATURE_COUNT = IDENTIFIABLE_FEATURE_COUNT + 2;
/**
* The meta object id for the '{@link org.eclipse.emf.cdo.releng.doc.article.impl.StructuralElementImpl
@@ -137,12 +145,20 @@ public interface ArticlePackage extends EPackage
int STRUCTURAL_ELEMENT__ID = LINK_TARGET__ID;
/**
- * The feature id for the '<em><b>Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Default Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int STRUCTURAL_ELEMENT__LABEL = LINK_TARGET__LABEL;
+ int STRUCTURAL_ELEMENT__DEFAULT_LABEL = LINK_TARGET__DEFAULT_LABEL;
+
+ /**
+ * The feature id for the '<em><b>Tooltip</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated
+ * @ordered
+ */
+ int STRUCTURAL_ELEMENT__TOOLTIP = LINK_TARGET__TOOLTIP;
/**
* The feature id for the '<em><b>Children</b></em>' containment reference list. <!-- begin-user-doc --> <!--
@@ -237,12 +253,20 @@ public interface ArticlePackage extends EPackage
int DOCUMENTATION__ID = STRUCTURAL_ELEMENT__ID;
/**
- * The feature id for the '<em><b>Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Default Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int DOCUMENTATION__LABEL = STRUCTURAL_ELEMENT__LABEL;
+ int DOCUMENTATION__DEFAULT_LABEL = STRUCTURAL_ELEMENT__DEFAULT_LABEL;
+
+ /**
+ * The feature id for the '<em><b>Tooltip</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated
+ * @ordered
+ */
+ int DOCUMENTATION__TOOLTIP = STRUCTURAL_ELEMENT__TOOLTIP;
/**
* The feature id for the '<em><b>Children</b></em>' containment reference list. <!-- begin-user-doc --> <!--
@@ -421,12 +445,20 @@ public interface ArticlePackage extends EPackage
int BODY__ID = STRUCTURAL_ELEMENT__ID;
/**
- * The feature id for the '<em><b>Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Default Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int BODY__LABEL = STRUCTURAL_ELEMENT__LABEL;
+ int BODY__DEFAULT_LABEL = STRUCTURAL_ELEMENT__DEFAULT_LABEL;
+
+ /**
+ * The feature id for the '<em><b>Tooltip</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated
+ * @ordered
+ */
+ int BODY__TOOLTIP = STRUCTURAL_ELEMENT__TOOLTIP;
/**
* The feature id for the '<em><b>Children</b></em>' containment reference list. <!-- begin-user-doc --> <!--
@@ -545,12 +577,20 @@ public interface ArticlePackage extends EPackage
int CATEGORY__ID = BODY__ID;
/**
- * The feature id for the '<em><b>Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Default Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated
+ * @ordered
+ */
+ int CATEGORY__DEFAULT_LABEL = BODY__DEFAULT_LABEL;
+
+ /**
+ * The feature id for the '<em><b>Tooltip</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int CATEGORY__LABEL = BODY__LABEL;
+ int CATEGORY__TOOLTIP = BODY__TOOLTIP;
/**
* The feature id for the '<em><b>Children</b></em>' containment reference list. <!-- begin-user-doc --> <!--
@@ -669,12 +709,20 @@ public interface ArticlePackage extends EPackage
int CHAPTER__ID = BODY__ID;
/**
- * The feature id for the '<em><b>Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Default Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int CHAPTER__LABEL = BODY__LABEL;
+ int CHAPTER__DEFAULT_LABEL = BODY__DEFAULT_LABEL;
+
+ /**
+ * The feature id for the '<em><b>Tooltip</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated
+ * @ordered
+ */
+ int CHAPTER__TOOLTIP = BODY__TOOLTIP;
/**
* The feature id for the '<em><b>Children</b></em>' containment reference list. <!-- begin-user-doc --> <!--
@@ -801,12 +849,20 @@ public interface ArticlePackage extends EPackage
int ARTICLE__ID = CHAPTER__ID;
/**
- * The feature id for the '<em><b>Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Default Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated
+ * @ordered
+ */
+ int ARTICLE__DEFAULT_LABEL = CHAPTER__DEFAULT_LABEL;
+
+ /**
+ * The feature id for the '<em><b>Tooltip</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int ARTICLE__LABEL = CHAPTER__LABEL;
+ int ARTICLE__TOOLTIP = CHAPTER__TOOLTIP;
/**
* The feature id for the '<em><b>Children</b></em>' containment reference list. <!-- begin-user-doc --> <!--
@@ -1149,12 +1205,20 @@ public interface ArticlePackage extends EPackage
int JAVA_ELEMENT__ID = LINK_TARGET__ID;
/**
- * The feature id for the '<em><b>Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Default Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int JAVA_ELEMENT__LABEL = LINK_TARGET__LABEL;
+ int JAVA_ELEMENT__DEFAULT_LABEL = LINK_TARGET__DEFAULT_LABEL;
+
+ /**
+ * The feature id for the '<em><b>Tooltip</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated
+ * @ordered
+ */
+ int JAVA_ELEMENT__TOOLTIP = LINK_TARGET__TOOLTIP;
/**
* The feature id for the '<em><b>Class File</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -1227,12 +1291,20 @@ public interface ArticlePackage extends EPackage
int EXTERNAL_TARGET__ID = LINK_TARGET__ID;
/**
- * The feature id for the '<em><b>Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Default Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int EXTERNAL_TARGET__LABEL = LINK_TARGET__LABEL;
+ int EXTERNAL_TARGET__DEFAULT_LABEL = LINK_TARGET__DEFAULT_LABEL;
+
+ /**
+ * The feature id for the '<em><b>Tooltip</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated
+ * @ordered
+ */
+ int EXTERNAL_TARGET__TOOLTIP = LINK_TARGET__TOOLTIP;
/**
* The feature id for the '<em><b>Url</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -1436,12 +1508,20 @@ public interface ArticlePackage extends EPackage
int SOURCE_CODE__ID = EXTERNAL_TARGET__ID;
/**
- * The feature id for the '<em><b>Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Default Label</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int SOURCE_CODE__LABEL = EXTERNAL_TARGET__LABEL;
+ int SOURCE_CODE__DEFAULT_LABEL = EXTERNAL_TARGET__DEFAULT_LABEL;
+
+ /**
+ * The feature id for the '<em><b>Tooltip</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated
+ * @ordered
+ */
+ int SOURCE_CODE__TOOLTIP = EXTERNAL_TARGET__TOOLTIP;
/**
* The feature id for the '<em><b>Url</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -1827,15 +1907,27 @@ public interface ArticlePackage extends EPackage
EClass getLinkTarget();
/**
- * Returns the meta object for the attribute '{@link org.eclipse.emf.cdo.releng.doc.article.LinkTarget#getLabel
- * <em>Label</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * Returns the meta object for the attribute '
+ * {@link org.eclipse.emf.cdo.releng.doc.article.LinkTarget#getDefaultLabel <em>Default Label</em>}'. <!--
+ * begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @return the meta object for the attribute '<em>Default Label</em>'.
+ * @see org.eclipse.emf.cdo.releng.doc.article.LinkTarget#getDefaultLabel()
+ * @see #getLinkTarget()
+ * @generated
+ */
+ EAttribute getLinkTarget_DefaultLabel();
+
+ /**
+ * Returns the meta object for the attribute '{@link org.eclipse.emf.cdo.releng.doc.article.LinkTarget#getTooltip
+ * <em>Tooltip</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
*
- * @return the meta object for the attribute '<em>Label</em>'.
- * @see org.eclipse.emf.cdo.releng.doc.article.LinkTarget#getLabel()
+ * @return the meta object for the attribute '<em>Tooltip</em>'.
+ * @see org.eclipse.emf.cdo.releng.doc.article.LinkTarget#getTooltip()
* @see #getLinkTarget()
* @generated
*/
- EAttribute getLinkTarget_Label();
+ EAttribute getLinkTarget_Tooltip();
/**
* Returns the meta object for class '{@link org.eclipse.emf.cdo.releng.doc.article.Callout <em>Callout</em>}'. <!--
@@ -2426,12 +2518,20 @@ public interface ArticlePackage extends EPackage
EClass LINK_TARGET = eINSTANCE.getLinkTarget();
/**
- * The meta object literal for the '<em><b>Label</b></em>' attribute feature. <!-- begin-user-doc --> <!--
+ * The meta object literal for the '<em><b>Default Label</b></em>' attribute feature. <!-- begin-user-doc --> <!--
+ * end-user-doc -->
+ *
+ * @generated
+ */
+ EAttribute LINK_TARGET__DEFAULT_LABEL = eINSTANCE.getLinkTarget_DefaultLabel();
+
+ /**
+ * The meta object literal for the '<em><b>Tooltip</b></em>' attribute feature. <!-- begin-user-doc --> <!--
* end-user-doc -->
*
* @generated
*/
- EAttribute LINK_TARGET__LABEL = eINSTANCE.getLinkTarget_Label();
+ EAttribute LINK_TARGET__TOOLTIP = eINSTANCE.getLinkTarget_Tooltip();
/**
* The meta object literal for the '{@link org.eclipse.emf.cdo.releng.doc.article.impl.CalloutImpl <em>Callout</em>}
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ArticleImpl.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ArticleImpl.java
index 157b63c4fd..b7ab72235f 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ArticleImpl.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ArticleImpl.java
@@ -55,6 +55,12 @@ public class ArticleImpl extends ChapterImpl implements Article
}
@Override
+ protected String getKind()
+ {
+ return "Article";
+ }
+
+ @Override
public void generate() throws IOException
{
HtmlWriter out = null;
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ArticlePackageImpl.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ArticlePackageImpl.java
index 319b36f372..6f04fb305e 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ArticlePackageImpl.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ArticlePackageImpl.java
@@ -593,7 +593,7 @@ public class ArticlePackageImpl extends EPackageImpl implements ArticlePackage
*
* @generated
*/
- public EAttribute getLinkTarget_Label()
+ public EAttribute getLinkTarget_DefaultLabel()
{
return (EAttribute)linkTargetEClass.getEStructuralFeatures().get(0);
}
@@ -603,6 +603,16 @@ public class ArticlePackageImpl extends EPackageImpl implements ArticlePackage
*
* @generated
*/
+ public EAttribute getLinkTarget_Tooltip()
+ {
+ return (EAttribute)linkTargetEClass.getEStructuralFeatures().get(1);
+ }
+
+ /**
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated
+ */
public EClass getCallout()
{
return calloutEClass;
@@ -948,7 +958,8 @@ public class ArticlePackageImpl extends EPackageImpl implements ArticlePackage
createEAttribute(structuralElementEClass, STRUCTURAL_ELEMENT__DOC);
linkTargetEClass = createEClass(LINK_TARGET);
- createEAttribute(linkTargetEClass, LINK_TARGET__LABEL);
+ createEAttribute(linkTargetEClass, LINK_TARGET__DEFAULT_LABEL);
+ createEAttribute(linkTargetEClass, LINK_TARGET__TOOLTIP);
calloutEClass = createEClass(CALLOUT);
createEReference(calloutEClass, CALLOUT__SNIPPET);
@@ -1115,7 +1126,10 @@ public class ArticlePackageImpl extends EPackageImpl implements ArticlePackage
initEClass(linkTargetEClass, LinkTarget.class, "LinkTarget", IS_ABSTRACT, !IS_INTERFACE,
IS_GENERATED_INSTANCE_CLASS);
- initEAttribute(getLinkTarget_Label(), ecorePackage.getEString(), "label", null, 1, 1, LinkTarget.class,
+ initEAttribute(getLinkTarget_DefaultLabel(), ecorePackage.getEString(), "defaultLabel", null, 0, 1,
+ LinkTarget.class, IS_TRANSIENT, IS_VOLATILE, !IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, IS_DERIVED,
+ IS_ORDERED);
+ initEAttribute(getLinkTarget_Tooltip(), ecorePackage.getEString(), "tooltip", null, 1, 1, LinkTarget.class,
IS_TRANSIENT, IS_VOLATILE, !IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, IS_DERIVED, IS_ORDERED);
EOperation op = addEOperation(linkTargetEClass, ecorePackage.getEString(), "linkFrom", 1, 1, IS_UNIQUE, IS_ORDERED);
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/CategoryImpl.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/CategoryImpl.java
index 26c601dd84..a70ff9bdc1 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/CategoryImpl.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/CategoryImpl.java
@@ -52,6 +52,12 @@ public class CategoryImpl extends BodyImpl implements Category
}
@Override
+ protected String getKind()
+ {
+ return "Category";
+ }
+
+ @Override
public PackageDoc getDoc()
{
return (PackageDoc)super.getDoc();
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ChapterImpl.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ChapterImpl.java
index f69ed27e99..0d306edd93 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ChapterImpl.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ChapterImpl.java
@@ -118,6 +118,12 @@ public class ChapterImpl extends BodyImpl implements Chapter
}
@Override
+ protected String getKind()
+ {
+ return "Chapter";
+ }
+
+ @Override
protected String createFullPath()
{
if (this instanceof Article)
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/DocumentationImpl.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/DocumentationImpl.java
index 8b80007602..cd3bd282ab 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/DocumentationImpl.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/DocumentationImpl.java
@@ -501,6 +501,12 @@ public class DocumentationImpl extends StructuralElementImpl implements Document
}
@Override
+ protected String getKind()
+ {
+ return "Documentation";
+ }
+
+ @Override
public RootDoc getDoc()
{
return (RootDoc)super.getDoc();
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ExternalTargetImpl.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ExternalTargetImpl.java
index 86a21476a2..ec65b1e83c 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ExternalTargetImpl.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/ExternalTargetImpl.java
@@ -124,9 +124,7 @@ public class ExternalTargetImpl extends LinkTargetImpl implements ExternalTarget
public String toString()
{
if (eIsProxy())
- {
return super.toString();
- }
StringBuffer result = new StringBuffer(super.toString());
result.append(" (url: ");
@@ -148,10 +146,9 @@ public class ExternalTargetImpl extends LinkTargetImpl implements ExternalTarget
}
@Override
- public String getLabel()
+ public String getTooltip()
{
- // TODO: implement ExternalTargetImpl.getLabel()
- throw new UnsupportedOperationException();
+ return JavaElementImpl.getTooltip(classDoc);
}
} // ExternalTargetImpl
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/JavaElementImpl.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/JavaElementImpl.java
index 44362535be..0ee35eee25 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/JavaElementImpl.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/JavaElementImpl.java
@@ -15,6 +15,9 @@ import org.eclipse.emf.cdo.releng.doc.article.util.ArticleUtil;
import org.eclipse.emf.ecore.EClass;
import com.sun.javadoc.ClassDoc;
+import com.sun.javadoc.Doc;
+import com.sun.javadoc.PackageDoc;
+import com.sun.javadoc.ProgramElementDoc;
import java.io.File;
@@ -158,10 +161,97 @@ public class JavaElementImpl extends LinkTargetImpl implements JavaElement
}
@Override
- public String getLabel()
+ public String getTooltip()
{
- // TODO: implement JavaElementImpl.getLabel()
- throw new UnsupportedOperationException();
+ return getTooltip(classDoc);
+ }
+
+ public static String getTooltip(Doc doc)
+ {
+ String kind = getKind(doc);
+ if (kind == null || kind.length() == 0)
+ {
+ return "";
+ }
+
+ if (doc instanceof ProgramElementDoc)
+ {
+ ProgramElementDoc programElementDoc = (ProgramElementDoc)doc;
+
+ ClassDoc containingClass = programElementDoc.containingClass();
+ if (containingClass != null)
+ {
+ return kind + " in " + containingClass.qualifiedTypeName();
+ }
+
+ PackageDoc containingPackage = programElementDoc.containingPackage();
+ if (containingPackage != null)
+ {
+ return kind + " in " + containingPackage.name();
+ }
+ }
+
+ return kind;
+ }
+
+ public static String getKind(Doc doc)
+ {
+ if (doc.isAnnotationType())
+ {
+ return "Annotation type";
+ }
+
+ if (doc.isAnnotationTypeElement())
+ {
+ return "Annotation element";
+ }
+
+ if (doc.isOrdinaryClass())
+ {
+ return "Class";
+ }
+
+ if (doc.isConstructor())
+ {
+ return "Constructor";
+ }
+
+ if (doc.isEnum())
+ {
+ return "Enum";
+ }
+
+ if (doc.isEnumConstant())
+ {
+ return "Enum constant";
+ }
+
+ if (doc.isError())
+ {
+ return "Error";
+ }
+
+ if (doc.isException())
+ {
+ return "Exception";
+ }
+
+ if (doc.isField())
+ {
+ return "Field";
+ }
+
+ if (doc.isInterface())
+ {
+ return "Interface";
+ }
+
+ if (doc.isMethod())
+ {
+ return "Method";
+ }
+
+ return null;
}
} // JavaElementImpl
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/LinkImpl.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/LinkImpl.java
index 561d4ca773..6ba5f37774 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/LinkImpl.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/LinkImpl.java
@@ -87,7 +87,9 @@ public class LinkImpl extends BodyElementImpl implements Link
LinkTarget oldTarget = target;
target = newTarget;
if (eNotificationRequired())
+ {
eNotify(new ENotificationImpl(this, Notification.SET, ArticlePackage.LINK__TARGET, oldTarget, target));
+ }
}
/**
@@ -172,10 +174,24 @@ public class LinkImpl extends BodyElementImpl implements Link
String label = tag.label();
if (label == null || label.length() == 0)
{
- label = tag.text();
+ label = target.getDefaultLabel();
+ if (label == null || label.length() == 0)
+ {
+ label = tag.text();
+ }
+ }
+
+ String tooltip = target.getTooltip();
+ if (tooltip != null && tooltip.length() != 0)
+ {
+ tooltip = " title=\"" + tooltip + "\"";
+ }
+ else
+ {
+ tooltip = "";
}
- return "<a href=\"" + href + "\">" + label + "</a>";
+ return "<a href=\"" + href + "\"" + tooltip + ">" + label + "</a>";
}
} // LinkImpl
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/StructuralElementImpl.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/StructuralElementImpl.java
index f20da7cada..9310b544d1 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/StructuralElementImpl.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/StructuralElementImpl.java
@@ -188,7 +188,9 @@ public abstract class StructuralElementImpl extends LinkTargetImpl implements St
public StructuralElement getParent()
{
if (eContainerFeatureID() != ArticlePackage.STRUCTURAL_ELEMENT__PARENT)
+ {
return null;
+ }
return (StructuralElement)eContainer();
}
@@ -210,24 +212,34 @@ public abstract class StructuralElementImpl extends LinkTargetImpl implements St
*/
public void setParent(StructuralElement newParent)
{
- if (newParent != eInternalContainer()
- || (eContainerFeatureID() != ArticlePackage.STRUCTURAL_ELEMENT__PARENT && newParent != null))
+ if (newParent != eInternalContainer() || eContainerFeatureID() != ArticlePackage.STRUCTURAL_ELEMENT__PARENT
+ && newParent != null)
{
if (EcoreUtil.isAncestor(this, newParent))
+ {
throw new IllegalArgumentException("Recursive containment not allowed for " + toString());
+ }
NotificationChain msgs = null;
if (eInternalContainer() != null)
+ {
msgs = eBasicRemoveFromContainer(msgs);
+ }
if (newParent != null)
+ {
msgs = ((InternalEObject)newParent).eInverseAdd(this, ArticlePackage.STRUCTURAL_ELEMENT__CHILDREN,
StructuralElement.class, msgs);
+ }
msgs = basicSetParent(newParent, msgs);
if (msgs != null)
+ {
msgs.dispatch();
+ }
}
else if (eNotificationRequired())
+ {
eNotify(new ENotificationImpl(this, Notification.SET, ArticlePackage.STRUCTURAL_ELEMENT__PARENT, newParent,
newParent));
+ }
}
/**
@@ -348,7 +360,9 @@ public abstract class StructuralElementImpl extends LinkTargetImpl implements St
return ((InternalEList<InternalEObject>)(InternalEList<?>)getChildren()).basicAdd(otherEnd, msgs);
case ArticlePackage.STRUCTURAL_ELEMENT__PARENT:
if (eInternalContainer() != null)
+ {
msgs = eBasicRemoveFromContainer(msgs);
+ }
return basicSetParent((StructuralElement)otherEnd, msgs);
}
return super.eInverseAdd(otherEnd, featureID, msgs);
@@ -500,7 +514,9 @@ public abstract class StructuralElementImpl extends LinkTargetImpl implements St
public String toString()
{
if (eIsProxy())
+ {
return super.toString();
+ }
StringBuffer result = new StringBuffer(super.toString());
result.append(" (title: ");
@@ -512,11 +528,19 @@ public abstract class StructuralElementImpl extends LinkTargetImpl implements St
}
@Override
- public String getLabel()
+ public String getDefaultLabel()
{
- return getTitle();
+ return title;
+ }
+
+ @Override
+ public String getTooltip()
+ {
+ return getKind() + " in " + getDocumentation().getTitle();
}
+ protected abstract String getKind();
+
public void generate() throws IOException
{
for (StructuralElement child : getChildren())
diff --git a/plugins/org.eclipse.net4j.db.doc/build.xml b/plugins/org.eclipse.net4j.db.doc/build.xml
index 3e6fab5c47..5a361cd8c0 100644
--- a/plugins/org.eclipse.net4j.db.doc/build.xml
+++ b/plugins/org.eclipse.net4j.db.doc/build.xml
@@ -5,9 +5,10 @@
<!-- THIS FILE HAS BEEN GENERATED, DO NOT CHANGE -->
<!-- =========================================== -->
- <property name="jdk.version" value="1.5.0" />
- <property name="emf.version" value="2.7.0" />
- <property name="platform.version" value="juno" />
+ <property name="jdk.link" value="http://download.oracle.com/javase/1.5.0/docs/api" />
+ <property name="platform.link"
+ value="http://help.eclipse.org/juno/topic/org.eclipse.platform.doc.isv/reference/api" />
+ <property name="emf.link" value="http://download.eclipse.org/modeling/emf/emf/javadoc/2.7.0" />
<property name="project.path" value="plugins/org.eclipse.net4j.db.doc" />
<property file="${project.path}/plugin.properties" />
@@ -117,9 +118,9 @@
<package name="org.eclipse.net4j.db.postgresql" />
</group>
- <link href="http://download.oracle.com/javase/${jdk.version}/docs/api" />
- <link href="http://help.eclipse.org/${platform.version}/topic/org.eclipse.platform.doc.isv/reference/api" />
- <link href="http://download.eclipse.org/modeling/emf/emf/javadoc/${emf.version}" />
+ <link href="${jdk.link}" />
+ <link href="${platform.link}" />
+ <link href="${emf.link}" />
<link href="MAKE-RELATIVE/org.eclipse.net4j.util.doc/javadoc" offline="true" packagelistloc="plugins/org.eclipse.net4j.util.doc/javadoc" />
<tag name="ADDED" description="Added" />
@@ -180,6 +181,11 @@
<exclude name="**/*.java" />
</fileset>
</copy>
+ <copy todir="${project.path}/images" verbose="true" failonerror="false">
+ <fileset dir="plugins/org.eclipse.emf.cdo.releng.doc/resources" defaultexcludes="true">
+ <include name="**/*" />
+ </fileset>
+ </copy>
<javadoc encoding="ISO-8859-1"
classpathref="javadoc.classpath"
@@ -194,6 +200,7 @@
<param name="-starttime" value="${start.time}" />
<param name="-basefolder" value="${basedir}" />
<param name="-project" value="org.eclipse.net4j.db.doc" />
+ <param name="-externals" value="${jdk.link};${platform.link};${emf.link}" />
</doclet>
<fileset dir="plugins">
diff --git a/plugins/org.eclipse.net4j.doc/build.xml b/plugins/org.eclipse.net4j.doc/build.xml
index 8953ecc9f3..d011804dc7 100644
--- a/plugins/org.eclipse.net4j.doc/build.xml
+++ b/plugins/org.eclipse.net4j.doc/build.xml
@@ -5,9 +5,10 @@
<!-- THIS FILE HAS BEEN GENERATED, DO NOT CHANGE -->
<!-- =========================================== -->
- <property name="jdk.version" value="1.5.0" />
- <property name="emf.version" value="2.7.0" />
- <property name="platform.version" value="juno" />
+ <property name="jdk.link" value="http://download.oracle.com/javase/1.5.0/docs/api" />
+ <property name="platform.link"
+ value="http://help.eclipse.org/juno/topic/org.eclipse.platform.doc.isv/reference/api" />
+ <property name="emf.link" value="http://download.eclipse.org/modeling/emf/emf/javadoc/2.7.0" />
<property name="project.path" value="plugins/org.eclipse.net4j.doc" />
<property file="${project.path}/plugin.properties" />
@@ -135,9 +136,9 @@
<package name="org.eclipse.net4j.ui" />
</group>
- <link href="http://download.oracle.com/javase/${jdk.version}/docs/api" />
- <link href="http://help.eclipse.org/${platform.version}/topic/org.eclipse.platform.doc.isv/reference/api" />
- <link href="http://download.eclipse.org/modeling/emf/emf/javadoc/${emf.version}" />
+ <link href="${jdk.link}" />
+ <link href="${platform.link}" />
+ <link href="${emf.link}" />
<link href="MAKE-RELATIVE/org.eclipse.net4j.util.doc/javadoc" offline="true" packagelistloc="plugins/org.eclipse.net4j.util.doc/javadoc" />
<tag name="ADDED" description="Added" />
@@ -208,6 +209,11 @@
<exclude name="**/*.java" />
</fileset>
</copy>
+ <copy todir="${project.path}/images" verbose="true" failonerror="false">
+ <fileset dir="plugins/org.eclipse.emf.cdo.releng.doc/resources" defaultexcludes="true">
+ <include name="**/*" />
+ </fileset>
+ </copy>
<javadoc encoding="ISO-8859-1"
classpathref="javadoc.classpath"
@@ -222,6 +228,7 @@
<param name="-starttime" value="${start.time}" />
<param name="-basefolder" value="${basedir}" />
<param name="-project" value="org.eclipse.net4j.doc" />
+ <param name="-externals" value="${jdk.link};${platform.link};${emf.link}" />
</doclet>
<fileset dir="plugins">
diff --git a/plugins/org.eclipse.net4j.util.doc/build.xml b/plugins/org.eclipse.net4j.util.doc/build.xml
index 1bdc38771d..a88d307827 100644
--- a/plugins/org.eclipse.net4j.util.doc/build.xml
+++ b/plugins/org.eclipse.net4j.util.doc/build.xml
@@ -5,9 +5,10 @@
<!-- THIS FILE HAS BEEN GENERATED, DO NOT CHANGE -->
<!-- =========================================== -->
- <property name="jdk.version" value="1.5.0" />
- <property name="emf.version" value="2.7.0" />
- <property name="platform.version" value="juno" />
+ <property name="jdk.link" value="http://download.oracle.com/javase/1.5.0/docs/api" />
+ <property name="platform.link"
+ value="http://help.eclipse.org/juno/topic/org.eclipse.platform.doc.isv/reference/api" />
+ <property name="emf.link" value="http://download.eclipse.org/modeling/emf/emf/javadoc/2.7.0" />
<property name="project.path" value="plugins/org.eclipse.net4j.util.doc" />
<property file="${project.path}/plugin.properties" />
@@ -152,9 +153,9 @@
<package name="org.eclipse.net4j.util.ui.widgets" />
</group>
- <link href="http://download.oracle.com/javase/${jdk.version}/docs/api" />
- <link href="http://help.eclipse.org/${platform.version}/topic/org.eclipse.platform.doc.isv/reference/api" />
- <link href="http://download.eclipse.org/modeling/emf/emf/javadoc/${emf.version}" />
+ <link href="${jdk.link}" />
+ <link href="${platform.link}" />
+ <link href="${emf.link}" />
<tag name="ADDED" description="Added" />
<tag name="Singleton" description="Singleton" />
@@ -214,6 +215,11 @@
<exclude name="**/*.java" />
</fileset>
</copy>
+ <copy todir="${project.path}/images" verbose="true" failonerror="false">
+ <fileset dir="plugins/org.eclipse.emf.cdo.releng.doc/resources" defaultexcludes="true">
+ <include name="**/*" />
+ </fileset>
+ </copy>
<javadoc encoding="ISO-8859-1"
classpathref="javadoc.classpath"
@@ -228,6 +234,7 @@
<param name="-starttime" value="${start.time}" />
<param name="-basefolder" value="${basedir}" />
<param name="-project" value="org.eclipse.net4j.util.doc" />
+ <param name="-externals" value="${jdk.link};${platform.link};${emf.link}" />
</doclet>
<fileset dir="plugins">

Back to the top
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/LinkTarget.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/LinkTarget.java
index 91911e6f66..32a7c3ced4 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/LinkTarget.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/LinkTarget.java
@@ -11,7 +11,8 @@ package org.eclipse.emf.cdo.releng.doc.article;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.eclipse.emf.cdo.releng.doc.article.LinkTarget#getLabel <em>Label</em>}</li>
+ * <li>{@link org.eclipse.emf.cdo.releng.doc.article.LinkTarget#getDefaultLabel <em>Default Label</em>}</li>
+ * <li>{@link org.eclipse.emf.cdo.releng.doc.article.LinkTarget#getTooltip <em>Tooltip</em>}</li>
* </ul>
* </p>
*
@@ -22,18 +23,33 @@ package org.eclipse.emf.cdo.releng.doc.article;
public interface LinkTarget extends Identifiable
{
/**
- * Returns the value of the '<em><b>Label</b></em>' attribute. <!-- begin-user-doc -->
+ * Returns the value of the '<em><b>Default Label</b></em>' attribute. <!-- begin-user-doc -->
+ * <p>
+ * If the meaning of the '<em>Default Label</em>' attribute isn't clear, there really should be more of a description
+ * here...
+ * </p>
+ * <!-- end-user-doc -->
+ *
+ * @return the value of the '<em>Default Label</em>' attribute.
+ * @see org.eclipse.emf.cdo.releng.doc.article.ArticlePackage#getLinkTarget_DefaultLabel()
+ * @model transient="true" changeable="false" volatile="true" derived="true"
+ * @generated
+ */
+ String getDefaultLabel();
+
+ /**
+ * Returns the value of the '<em><b>Tooltip</b></em>' attribute. <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Label</em>' attribute isn't clear, there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
*
* @return the value of the '<em>Label</em>' attribute.
* @see org.eclipse.emf.cdo.releng.doc.article.ArticlePackage#getLinkTarget_Label()
* @model required="true" transient="true" changeable="false" volatile="true" derived="true"
* @generated
*/
- String getLabel();
+ String getTooltip();
/**
* <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -22,18 +23,33 @@ package org.eclipse.emf.cdo.releng.doc.article;
* <!-- end-user-doc -->
*
- * @return the value of the '<em>Label</em>' attribute.
- * @see org.eclipse.emf.cdo.releng.doc.article.ArticlePackage#getLinkTarget_Label()
+ * @return the value of the '<em>Tooltip</em>' attribute.
+ * @see org.eclipse.emf.cdo.releng.doc.article.ArticlePackage#getLinkTarget_Tooltip()
* @model required="true" transient="true" changeable="false" volatile="true" derived="true"
* @generated
diff --git a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/LinkTargetImpl.java b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/LinkTargetImpl.java
index af647594ba..a4e3300485 100644
--- a/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/LinkTargetImpl.java
+++ b/plugins/org.eclipse.emf.cdo.releng.doc/src/org/eclipse/emf/cdo/releng/doc/article/impl/LinkTargetImpl.java
@@ -19,7 +19,8 @@ import org.eclipse.emf.ecore.impl.EObjectImpl;
* The following features are implemented:
* <ul>
* <li>{@link org.eclipse.emf.cdo.releng.doc.article.impl.LinkTargetImpl#getId <em>Id</em>}</li>
- * <li>{@link org.eclipse.emf.cdo.releng.doc.article.impl.LinkTargetImpl#getLabel <em>Label</em>}</li>
+ * <li>{@link org.eclipse.emf.cdo.releng.doc.article.impl.LinkTargetImpl#getDefaultLabel <em>Default Label</em>}</li>
+ * <li>{@link org.eclipse.emf.cdo.releng.doc.article.impl.LinkTargetImpl#getTooltip <em>Tooltip</em>}</li>
* </ul>
* </p>
*
@@ -37,14 +38,24 @@ public abstract class LinkTargetImpl extends EObjectImpl implements LinkTarget
protected static final Object ID_EDEFAULT = null;
/**
* The default value of the '{@link #getLabel() <em>Label</em>}' attribute. <!-- begin-user-doc --> <!-- end-user-doc
* -->
*
- * @see #getLabel()
+ * @see #getDefaultLabel()
* @generated
* @ordered
*/
- protected static final String LABEL_EDEFAULT = null;
+ protected static final String DEFAULT_LABEL_EDEFAULT = null;
+
+ /**
+ * The default value of the '{@link #getTooltip() <em>Tooltip</em>}' attribute. <!-- begin-user-doc --> <!--
+ * end-user-doc -->
+ *
+ * @see #getTooltip()
+ * @generated
+ * @ordered
+ */
+ protected static final String TOOLTIP_EDEFAULT = null;
/**
* <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -79,7 +90,17 @@ public abstract class LinkTargetImpl extends EObjectImpl implements LinkTarget
*
* @generated NOT
*/
- public abstract String getLabel();
+ public String getDefaultLabel()
+ {
+ return null;
+ }
+
+ /**
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @generated NOT
+ */
+ public abstract String getTooltip();
/**
* <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -100,8 +121,10 @@ public abstract class LinkTargetImpl extends EObjectImpl implements LinkTarget
{
case ArticlePackage.LINK_TARGET__ID:
return getId();
- case ArticlePackage.LINK_TARGET__LABEL:
- return getLabel();
+ case ArticlePackage.LINK_TARGET__DEFAULT_LABEL:
+ return getDefaultLabel();
+ case ArticlePackage.LINK_TARGET__TOOLTIP:
+ return getTooltip();
}
return super.eGet(featureID, resolve, coreType);
}
@@ -118,8 +141,11 @@ public abstract class LinkTargetImpl extends EObjectImpl implements LinkTarget
{
case ArticlePackage.LINK_TARGET__ID:
return ID_EDEFAULT == null ? getId() != null : !ID_EDEFAULT.equals(getId());
- case ArticlePackage.LINK_TARGET__LABEL:
- return LABEL_EDEFAULT == null ? getLabel() != null : !LABEL_EDEFAULT.equals(getLabel());
+ case ArticlePackage.LINK_TARGET__DEFAULT_LABEL:
+ return DEFAULT_LABEL_EDEFAULT == null ? getDefaultLabel() != null : !DEFAULT_LABEL_EDEFAULT
+ .equals(getDefaultLabel());
+ case ArticlePackage.LINK_TARGET__TOOLTIP:
+ return TOOLTIP_EDEFAULT == null ? getTooltip() != null : !TOOLTIP_EDEFAULT.equals(getTooltip());
}
return super.eIsSet(featureID);
}
@@ -37,14 +38,24 @@ public abstract class LinkTargetImpl extends EObjectImpl implements LinkTarget
protected static final Object ID_EDEFAULT = null;
/**
- * The default value of the '{@link #getLabel() <em>Label</em>}' attribute. <!-- begin-user-doc --> <!-- end-user-doc
- * -->
+ * The default value of the '{@link #getDefaultLabel() <em>Default Label</em>}' attribute. <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
*